@@ -137,6 +137,7 @@ specified in C<data> if provided, rather than the moduletree itself.
 #
 
 sub _search_module_tree {
+
     my $self = shift;
     my $conf = $self->configure_object;
     my %hash = @_;
@@ -153,7 +154,13 @@ sub _search_module_tree {
                      store      => \$type },
     };
 
-    my $args = check( $tmpl, \%hash ) or return;
+    my $args = do {
+        ### don't check the template for sanity
+        ### -- we know it's good and saves a lot of performance
+        local $Params::Check::SANITY_CHECK_TEMPLATE = 0;
+
+        check( $tmpl, \%hash );
+    } or return;
 
     {   local $Params::Check::VERBOSE = 0;
 
@@ -314,24 +321,7 @@ sub _all_installed {
 
                     return if $seen{$mod}++;
 
-                    ### From John Malmberg: This is failing on VMS 
-                    ### because ODS-2 does not retain the case of 
-                    ### filenames that are created.
-                    ### The problem is the filename is being converted 
-                    ### to a module name and then looked up in the 
-                    ### %$modtree hash.
-                    ### 
-                    ### As a fix, we do a search on VMS instead --
-                    ### more cpu cycles, but it gets around the case
-                    ### problem --kane
-                    my ($modobj) = do {
-                        ON_VMS
-                            ? $self->search( 
-                                    type    => 'module',
-                                    allow   => [qr/^$mod$/i],
-                                )      
-                            : $self->module_tree($mod) 
-                    };
+                    my $modobj = $self->module_tree($mod);
                     
                     ### seperate return, a list context return with one ''
                     ### in it, is also true!
