@@ -405,14 +405,16 @@ sub _build_trees {
     return unless $self->{_modtree} && $self->{_authortree};
 
     ### update them if the other sources are also deemed out of date
-    unless( $uptodate ) {
+    if( not $uptodate and $conf->get_conf('enable_custom_sources') ) {
         $self->__update_custom_module_sources( verbose => $args->{verbose} ) 
             or error(loc("Could not update custom module sources"));
     }      
 
-    ### add custom sources here
-    $self->__create_custom_module_entries( verbose => $args->{verbose} )
-        or error(loc("Could not create custom module entries"));
+    ### add custom sources here if enabled
+    if( $conf->get_conf('enable_custom_sources') ) {
+        $self->__create_custom_module_entries( verbose => $args->{verbose} )
+            or error(loc("Could not create custom module entries"));
+    }
 
     ### write the stored files to disk, so we can keep using them
     ### from now on, till they become invalid
@@ -741,6 +743,8 @@ sub _create_mod_tree {
 
     my $dslip_tree = $self->__create_dslip_tree( %$args );
 
+$DB::single = 1;
+
     ### extract the file ###
     my $ae      = Archive::Extract->new( archive => $file ) or return;
     my $out     = STRIP_GZ_SUFFIX->($file);
@@ -1040,11 +1044,8 @@ sub _add_custom_module_source {
     
     check( $tmpl, \%hash ) or return;
     
-    my $index = File::Spec->catfile(
-                    $conf->get_conf('base'),
-                    $conf->_get_build('custom_sources'),        
-                    $self->_uri_encode( uri => $uri ),
-                );     
+    ### what index file should we use on disk?
+    my $index = $self->__custom_module_source_index_file( uri => $uri );
 
     ### already have it.
     if( IS_FILE->( $index ) ) {
@@ -1061,12 +1062,17 @@ sub _add_custom_module_source {
     
     ### write the file
     my $fh = OPEN_FILE->( $index => '>' ) or do {
-        error(loc("Could not write index file for '%1'", $uri));
+        error(loc("Could not open index file for '%1'", $uri));
         return;
     };
     
-    ### basically we 'touched' it.
-    close $fh;
+    ### basically we 'touched' it. Check the return value, may be 
+    ### important on win32 and similar OS, where there's file length
+    ### limits
+    close $fh or do {
+        error(loc("Could not write index file to disk for '%1'", $uri));
+        return;
+    };        
         
     $self->__update_custom_module_source(
                 remote  => $uri,
@@ -1082,6 +1088,34 @@ sub _add_custom_module_source {
     return $index;
 }
 
+=head2 $index = $cb->__custom_module_source_index_file( uri => $uri );
+
+Returns the full path to the encoded index file for C<$uri>, as used by
+all C<custom module source> routines.
+
+=cut
+
+sub __custom_module_source_index_file {
+    my $self = shift;
+    my $conf = $self->configure_object;
+    my %hash = @_;
+    
+    my($verbose,$uri);
+    my $tmpl = {   
+        uri     => { required => 1, store => \$uri }
+    };
+    
+    check( $tmpl, \%hash ) or return;
+    
+    my $index = File::Spec->catfile(
+                    $conf->get_conf('base'),
+                    $conf->_get_build('custom_sources'),        
+                    $self->_uri_encode( uri => $uri ),
+                );     
+
+    return $index;
+}
+
 =head2 $file = $cb->_remove_custom_module_source( uri => URI, [verbose => BOOL] ); 
 
 Removes a custom index file based on the URI provided.
@@ -1144,6 +1178,12 @@ Returns a list of key value pairs as follows:
 sub __list_custom_module_sources {
     my $self = shift;
     my $conf = $self->configure_object;
+    
+    my($verbose);
+    my $tmpl = {   
+        verbose => { default => $conf->get_conf('verbose'),
+                     store   => \$verbose },
+    };    
 
     my $dir = File::Spec->catdir(
                     $conf->get_conf('base'),
@@ -1151,7 +1191,7 @@ sub __list_custom_module_sources {
                 );
 
     unless( IS_DIR->( $dir ) ) {
-        msg(loc("No '%1' dir, skipping custom sources", $dir));
+        msg(loc("No '%1' dir, skipping custom sources", $dir), $verbose);
         return;
     }
     
