@@ -40,7 +40,7 @@ CPANPLUS::Selfupdate
 
     my $Modules = {
         dependencies => {
-            'File::Fetch'               => '0.13_02', # win32 file:// support
+            'File::Fetch'               => '0.15_02', # lynx & 404 handling
             'File::Spec'                => '0.82',
             'IPC::Cmd'                  => '0.36', # 5.6.2 compat: 2-arg open
             'Locale::Maketext::Simple'  => '0.01',
@@ -54,7 +54,7 @@ CPANPLUS::Selfupdate
                                                    # Address ~0 overflow issue
             'Params::Check'             => '0.22',
             'Package::Constants'        => '0.01',
-            'Term::UI'                  => '0.05',
+            'Term::UI'                  => '0.18', # option parsing
             'Test::Harness'             => '2.62', # due to bug #19505
                                                    # only 2.58 and 2.60 are bad
             'Test::More'                => '0.47', # to run our tests
@@ -65,6 +65,8 @@ CPANPLUS::Selfupdate
             'Module::CoreList'          => '2.09',
             'Module::Pluggable'         => '2.4',
             'Module::Loaded'            => '0.01',
+            'Parse::CPAN::Meta'         => '0.02', # config_requires support
+            'ExtUtils::Install'         => '1.42', # uninstall outside @INC
         },
     
         features => {
@@ -82,9 +84,8 @@ CPANPLUS::Selfupdate
                 sub { return 1 },   # always enabled
             ],            
             cpantest        => [
-                {
-                    'YAML::Tiny'     => '0.0',
-                    'Test::Reporter' => '1.34',
+                { 'Test::Reporter'  => '1.34',
+                  'YAML::Tiny'      => '0.0'
                 },
                 sub { 
                     my $cb = shift;
