@@ -24,7 +24,7 @@ BEGIN {
 
     ### and add them to the environment, so shellouts get them
     $old_env_perl5lib = $ENV{'PERL5LIB'};
-    $ENV{'PERL5LIB'}  = join ':', 
+    $ENV{'PERL5LIB'}  = join $Config{'path_sep'}, 
                         grep { defined } $ENV{'PERL5LIB'}, @paths, @rel2abs;
     
     ### add our own path to the front of $ENV{PATH}, so that cpanp-run-perl
@@ -62,10 +62,10 @@ END {
         ### path is "magic" on VMS, we can not tell if it really existed before
         ### this was run, because VMS will magically pretend that a PATH
         ### environment variable exists set to the current working directory
-        $ENV{PATH} = $old_path;
+        $ENV{PATH} = $old_env_path;
 
-        if (defined $old_perl5lib) {
-            $ENV{PERL5LIB} = $old_perl5lib;
+        if (defined $old_env_perl5lib) {
+            $ENV{PERL5LIB} = $old_env_perl5lib;
         } else {
             delete $ENV{PERL5LIB};
         }
@@ -96,6 +96,13 @@ use constant TEST_CONF_INST_MODULE      => 'Foo::Bar';
 use constant TEST_CONF_INVALID_MODULE   => 'fnurk';
 use constant TEST_CONF_MIRROR_DIR       => 'dummy-localmirror';
 use constant TEST_CONF_CPAN_DIR         => 'dummy-CPAN';
+use constant TEST_CONF_CPANPLUS_DIR     => 'dummy-cpanplus';
+use constant TEST_CONF_INSTALL_DIR      => File::Spec->rel2abs(
+                                                File::Spec->catdir(      
+                                                    TEST_CONF_CPANPLUS_DIR,
+                                                    'install'
+                                                )
+                                            );       
 
 ### we might need this Some Day when we're installing into
 ### our own sandbox. see t/20.t for details
@@ -131,13 +138,7 @@ use constant TEST_CONF_CPAN_DIR         => 'dummy-CPAN';
 #     ' INSTALLSITEMAN3DIR=' . TEST_INSTALL_DIR_MAN3;
 
 
-sub gimme_conf { 
-
-    ### don't load any other configs than the heuristic one
-    ### during tests. They might hold broken/incorrect data
-    ### for our test suite. Bug [perl #43629] showed this.
-    my $conf = CPANPLUS::Configure->new( load_configs => 0 );
-
+sub dummy_cpan_dir {
     ### VMS needs this in directory format for rel2abs
     my $test_dir = $^O eq 'VMS'
                     ? File::Spec->catdir(TEST_CONF_CPAN_DIR)
@@ -149,13 +150,25 @@ sub gimme_conf {
     ### According to John M: the hosts path needs to be in UNIX format.  
     ### File::Spec::Unix->rel2abs does not work at all on VMS
     $abs_test_dir    = VMS::Filespec::unixify( $abs_test_dir ) if $^O eq 'VMS';
+
+    return $abs_test_dir;
+}
+
+sub gimme_conf { 
+
+    ### don't load any other configs than the heuristic one
+    ### during tests. They might hold broken/incorrect data
+    ### for our test suite. Bug [perl #43629] showed this.
+    my $conf = CPANPLUS::Configure->new( load_configs => 0 );
+
+    my $dummy_cpan = dummy_cpan_dir();
     
     $conf->set_conf( hosts  => [ { 
-                        path        => $abs_test_dir,
+                        path        => $dummy_cpan,
                         scheme      => 'file',
                     } ],      
     );
-    $conf->set_conf( base       => File::Spec->rel2abs('dummy-cpanplus') );
+    $conf->set_conf( base       => File::Spec->rel2abs(TEST_CONF_CPANPLUS_DIR));
     $conf->set_conf( dist_type  => '' );
     $conf->set_conf( signature  => 0 );
     $conf->set_conf( verbose    => 1 ) if $ENV{ $Env };
@@ -272,7 +285,7 @@ sub _clean_test_dir {
                 ### mailing-lists/perl5-porters/2007-10/msg00064.html
                 ### for details -- the below regex could use some touchups
                 ### according to John. M.            
-                $file =~ s/\.dir//i if $^O eq 'VMS';
+                $file =~ s/\.dir$//i if $^O eq 'VMS';
                 
                 my $dirpath = File::Spec->catdir( $dir, $file );
 
